package com.goldenwater.slaj.eutr.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.eutr.domain.BisEutrTqueOpt;

@Mapper
public interface BisEutrTqueOptMapper {
    BisEutrTqueOpt selectBisEutrTqueOptByGuid(String guid);
    List<BisEutrTqueOpt> selectBisEutrTqueOptList(BisEutrTqueOpt bisEutrTqueOpt);
    int insertBisEutrTqueOpt(BisEutrTqueOpt bisEutrTqueOpt);
    int updateBisEutrTqueOpt(BisEutrTqueOpt bisEutrTqueOpt);
    int deleteBisEutrTqueOptByGuid(String guid);
    int deleteBisEutrTqueOptByGuids(String[] guids);
}
